@@ -23,17 +23,17 @@ class Client:
         self.location = location
         self.should_stop = False
 
-    def on_message(self, message):
+    def on_message(self, ws, message):
         self.smart_system.on_message(message)
 
-    def on_error(self, error):
+    def on_error(self, ws, error):
         self.logger.error(f"error : {error}")
         self.smart_system.set_ws_status(False)
 
     def is_connected(self):
         return self.live
 
-    def on_close(self):
+    def on_close(self, ws):
         self.live = False
         self.logger.info("Connection close to gardena API")
         self.smart_system.set_ws_status(False)
@@ -41,7 +41,7 @@ class Client:
             self.logger.info("Restarting websocket")
             self.smart_system.start_ws(self.location)
 
-    def on_open(self):
+    def on_open(self, ws):
         self.logger.info("Connected to Gardena API")
         self.live = True
         self.smart_system.set_ws_status(True)
@@ -227,6 +227,9 @@ class SmartSystem:
                 self.logger.error("No device found....")
             else:
                 devices_smart_system = {}
+                self.logger.debug(f'Received devices in  message')
+                self.logger.debug("------- Beginning of message ---------")
+                self.logger.debug(response_data["included"])
                 for device in response_data["included"]:
                     real_id = device["id"].split(":")[0]
                     if real_id not in devices_smart_system:
@@ -236,7 +239,7 @@ class SmartSystem:
                             devices_smart_system[real_id][device["type"]] = []
                         devices_smart_system[real_id][device["type"]].append(device)
                 for parsed_device in devices_smart_system.values():
-                    device_obj = DeviceFactory.build(self, parsed_device)
+                    device_obj = DeviceFactory.build(location, parsed_device)
                     if device_obj is not None:
                         location.add_device(device_obj)
 
